package integrationtest;

import org.openqa.selenium.*;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.edge.EdgeDriver;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.htmlunit.HtmlUnitDriver;
import org.openqa.selenium.ie.InternetExplorerDriver;
import org.openqa.selenium.safari.SafariDriver;

/**
 * Wrapper fuer Selenium-WebDriver fuer waehlbaren Webbrowser und als AutoCloseable
 */
public class WebDriverWrapper implements AutoCloseable
{
   private WebDriver webDriver;

   /**
    * Selenium-WebDriver fuer waehlbaren Webbrowser instanziieren.
    * @param browserName      leer fuer HtmlUnitDriver oder
    *                         FF, Chrome, Edge, IE oder Safari fuer gewuenschten Webbrowser.
    * @param webDriverExePath leer fuer HtmlUnitDriver, FF und Safari;
    *                         fuer Chrome und IE wird Pfad zum externen WebDriver.exe benoetigt,
    *                         z.B. zu chromedriver.exe, iexploredriver.exe bzw. MicrosoftWebDriver.exe.
    */
   public WebDriverWrapper( String browserName, String webDriverExePath )
   {
      if( browserName != null ) {
         String brwsr = browserName.trim().toLowerCase();
         String wbdrv = ( webDriverExePath != null ) ? webDriverExePath.trim() : null;
         if( brwsr.contains( "firefox" ) || brwsr.contains( "ff" ) ) {
            webDriver = new FirefoxDriver();
         } else if( brwsr.contains( "chrome" ) ) {
            if( wbdrv != null ) { System.setProperty( "webdriver.chrome.driver", wbdrv ); }
            webDriver = new ChromeDriver();
         } else if( brwsr.contains( "edge" ) ) {
            if( wbdrv == null ) {
               wbdrv = "C:\\Program Files (x86)\\Microsoft Web Driver\\MicrosoftWebDriver.exe";
            }
            System.setProperty( "webdriver.edge.driver", wbdrv );
            webDriver = new EdgeDriver();
         } else if( brwsr.contains( "internetexplorer" ) || brwsr.contains( "ie" ) ) {
            if( wbdrv != null ) { System.setProperty( "webdriver.ie.driver", wbdrv ); }
            webDriver = new InternetExplorerDriver();
         } else if( brwsr.contains( "safari" ) ) {
            webDriver = new SafariDriver();
         }
      }
      if( webDriver == null ) {
         webDriver = new HtmlUnitDriver();
      }
   }

   public WebDriver getWebDriver()
   {
      return webDriver;
   }

   @Override
   public void close()
   {
      webDriver.quit();
      webDriver = null;
   }
}
